@@ -18,6 +18,7 @@ import (
 	"github.com/derailed/k9s/internal/config/mock"
 	m "github.com/petergtz/pegomock"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 )
 
@@ -48,22 +49,21 @@ func TestConfigSave(t *testing.T) {
 		},
 	}
 
-	for k := range uu {
+	for k, u := range uu {
 		xdg.Reload()
-		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, err := c.K9s.ActivateContext(u.ct)
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			if u.flags != nil {
 				c.K9s.Override(u.k9sFlags)
-				assert.NoError(t, c.Refine(u.flags, u.k9sFlags, client.NewConfig(u.flags)))
+				require.NoError(t, c.Refine(u.flags, u.k9sFlags, client.NewConfig(u.flags)))
 			}
-			assert.NoError(t, c.Save(true))
+			require.NoError(t, c.Save(true))
 			bb, err := os.ReadFile(config.AppConfigFile)
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			ee, err := os.ReadFile("testdata/configs/default.yaml")
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			assert.Equal(t, string(ee), string(bb))
 		})
 	}
@@ -112,10 +112,10 @@ func TestSetActiveView(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			if u.flags != nil {
-				assert.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
+				require.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
 				c.K9s.Override(u.k9sFlags)
 			}
 			c.SetActiveView(u.view)
@@ -155,10 +155,10 @@ func TestActiveContextName(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			if u.flags != nil {
-				assert.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
+				require.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
 				c.K9s.Override(u.k9sFlags)
 			}
 			assert.Equal(t, u.e, c.ActiveContextName())
@@ -181,14 +181,22 @@ func TestActiveView(t *testing.T) {
 		"empty": {
 			e: data.DefaultView,
 		},
+
 		"not-exists": {
 			ct: "fred",
 			e:  data.DefaultView,
 		},
+
 		"happy": {
 			ct: "ct-1-1",
 			e:  data.DefaultView,
 		},
+
+		"happy1": {
+			ct: "ct-1-2",
+			e:  data.DefaultView,
+		},
+
 		"cli-override": {
 			flags: &genericclioptions.ConfigFlags{
 				KubeConfig: &cfgFile,
@@ -203,10 +211,10 @@ func TestActiveView(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			if u.flags != nil {
-				assert.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
+				require.NoError(t, c.Refine(u.flags, nil, client.NewConfig(u.flags)))
 				c.K9s.Override(u.k9sFlags)
 			}
 			assert.Equal(t, u.e, c.ActiveView())
@@ -232,7 +240,7 @@ func TestFavNamespaces(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			assert.Equal(t, u.e, c.FavNamespaces())
 		})
@@ -257,7 +265,7 @@ func TestContextAliasesPath(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			assert.Equal(t, u.e, c.ContextAliasesPath())
 		})
@@ -285,7 +293,7 @@ func TestContextPluginsPath(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c := mock.NewMockConfig()
+			c := mock.NewMockConfig(t)
 			_, _ = c.K9s.ActivateContext(u.ct)
 			s, err := c.ContextPluginsPath()
 			if err != nil {
@@ -343,13 +351,13 @@ func TestConfigActivateContext(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			cfg := mock.NewMockConfig()
+			cfg := mock.NewMockConfig(t)
 			ct, err := cfg.ActivateContext(u.ct)
 			if err != nil {
 				assert.Equal(t, u.err, err.Error())
 				return
 			}
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			assert.Equal(t, u.cl, ct.ClusterName)
 		})
 	}
@@ -390,12 +398,12 @@ func TestConfigCurrentContext(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			cfg := mock.NewMockConfig()
+			cfg := mock.NewMockConfig(t)
 
 			err := cfg.Refine(u.flags, nil, client.NewConfig(u.flags))
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			ct, err := cfg.CurrentContext()
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			assert.Equal(t, u.cluster, ct.ClusterName)
 			assert.Equal(t, u.namespace, ct.Namespace.Active)
 		})
@@ -408,7 +416,7 @@ func TestConfigRefine(t *testing.T) {
 		cl1           = "cl-1"
 		ct2           = "ct-1-2"
 		ns1, ns2, nsx = "ns-1", "ns-2", "ns-x"
-		true          = true
+		trueVal       = true
 	)
 
 	uu := map[string]struct {
@@ -465,7 +473,7 @@ func TestConfigRefine(t *testing.T) {
 				Namespace:  &ns2,
 			},
 			k9sFlags: &config.Flags{
-				AllNamespaces: &true,
+				AllNamespaces: &trueVal,
 			},
 			cluster:   "cl-1",
 			context:   "ct-1-1",
@@ -510,13 +518,13 @@ func TestConfigRefine(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			cfg := mock.NewMockConfig()
+			cfg := mock.NewMockConfig(t)
 
 			err := cfg.Refine(u.flags, u.k9sFlags, client.NewConfig(u.flags))
 			if err != nil {
 				assert.Equal(t, u.err, err.Error())
 			} else {
-				assert.Nil(t, err)
+				require.NoError(t, err)
 				assert.Equal(t, u.context, cfg.K9s.ActiveContextName())
 				assert.Equal(t, u.namespace, cfg.ActiveNamespace())
 			}
@@ -525,61 +533,63 @@ func TestConfigRefine(t *testing.T) {
 }
 
 func TestConfigValidate(t *testing.T) {
-	cfg := mock.NewMockConfig()
+	cfg := mock.NewMockConfig(t)
 	cfg.SetConnection(mock.NewMockConnection())
 
-	assert.Nil(t, cfg.Load("testdata/configs/k9s.yaml", true))
+	require.NoError(t, cfg.Load("testdata/configs/k9s.yaml", true))
 	cfg.Validate("ct-1-1", "cl-1")
 }
 
 func TestConfigLoad(t *testing.T) {
-	cfg := mock.NewMockConfig()
+	cfg := mock.NewMockConfig(t)
 
-	assert.Nil(t, cfg.Load("testdata/configs/k9s.yaml", true))
+	require.NoError(t, cfg.Load("testdata/configs/k9s.yaml", true))
 	assert.Equal(t, 2, cfg.K9s.RefreshRate)
 	assert.Equal(t, int64(200), cfg.K9s.Logger.TailCount)
 	assert.Equal(t, 2000, cfg.K9s.Logger.BufferSize)
 }
 
 func TestConfigLoadCrap(t *testing.T) {
-	cfg := mock.NewMockConfig()
+	cfg := mock.NewMockConfig(t)
 
-	assert.NotNil(t, cfg.Load("testdata/configs/k9s_not_there.yaml", true))
+	assert.Error(t, cfg.Load("testdata/configs/k9s_not_there.yaml", true))
 }
 
 func TestConfigSaveFile(t *testing.T) {
-	cfg := mock.NewMockConfig()
+	cfg := mock.NewMockConfig(t)
 
-	assert.Nil(t, cfg.Load("testdata/configs/k9s.yaml", true))
+	require.NoError(t, cfg.Load("testdata/configs/k9s.yaml", true))
 
 	cfg.K9s.RefreshRate = 100
+	cfg.K9s.APIServerTimeout = "30s"
 	cfg.K9s.ReadOnly = true
 	cfg.K9s.Logger.TailCount = 500
 	cfg.K9s.Logger.BufferSize = 800
+	cfg.K9s.UI.UseFullGVRTitle = true
 	cfg.Validate("ct-1-1", "cl-1")
 
-	path := filepath.Join("/tmp", "k9s.yaml")
-	assert.NoError(t, cfg.SaveFile(path))
+	path := filepath.Join(os.TempDir(), "k9s.yaml")
+	require.NoError(t, cfg.SaveFile(path))
 	raw, err := os.ReadFile(path)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	ee, err := os.ReadFile("testdata/configs/expected.yaml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, string(ee), string(raw))
 }
 
 func TestConfigReset(t *testing.T) {
-	cfg := mock.NewMockConfig()
-	assert.Nil(t, cfg.Load("testdata/configs/k9s.yaml", true))
+	cfg := mock.NewMockConfig(t)
+	require.NoError(t, cfg.Load("testdata/configs/k9s.yaml", true))
 	cfg.Reset()
 	cfg.Validate("ct-1-1", "cl-1")
 
-	path := filepath.Join("/tmp", "k9s.yaml")
-	assert.NoError(t, cfg.SaveFile(path))
+	path := filepath.Join(os.TempDir(), "k9s.yaml")
+	require.NoError(t, cfg.SaveFile(path))
 
 	bb, err := os.ReadFile(path)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	ee, err := os.ReadFile("testdata/configs/k9s.yaml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, string(ee), string(bb))
 }
 
