@@ -17,6 +17,7 @@ import (
 	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/watch"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -24,7 +25,7 @@ import (
 )
 
 func TestTableReconcile(t *testing.T) {
-	ta := NewTable(client.NewGVR("v1/pods"))
+	ta := NewTable(client.PodGVR)
 	ta.SetNamespace(client.NamespaceAll)
 
 	f := makeFactory()
@@ -33,7 +34,7 @@ func TestTableReconcile(t *testing.T) {
 	ctx = context.WithValue(ctx, internal.KeyFields, "")
 	ctx = context.WithValue(ctx, internal.KeyWithMetrics, false)
 	err := ta.reconcile(ctx)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	data := ta.Peek()
 	assert.Equal(t, 25, data.HeaderCount())
 	assert.Equal(t, 1, data.RowCount())
@@ -41,18 +42,18 @@ func TestTableReconcile(t *testing.T) {
 }
 
 func TestTableList(t *testing.T) {
-	ta := NewTable(client.NewGVR("v1/pods"))
+	ta := NewTable(client.PodGVR)
 	ta.SetNamespace("blee")
 
 	acc := accessor{}
 	ctx := context.WithValue(context.Background(), internal.KeyFactory, makeFactory())
 	rows, err := ta.list(ctx, &acc)
-	assert.Nil(t, err)
-	assert.Equal(t, 1, len(rows))
+	require.NoError(t, err)
+	assert.Len(t, rows, 1)
 }
 
 func TestTableGet(t *testing.T) {
-	ta := NewTable(client.NewGVR("v1/pods"))
+	ta := NewTable(client.PodGVR)
 	ta.SetNamespace("blee")
 
 	f := makeFactory()
@@ -60,37 +61,32 @@ func TestTableGet(t *testing.T) {
 	ctx := context.WithValue(context.Background(), internal.KeyFactory, f)
 	ctx = context.WithValue(ctx, internal.KeyWithMetrics, false)
 	row, err := ta.Get(ctx, "fred")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, row)
-	assert.Equal(t, 5, len(row.(*render.PodWithMetrics).Raw.Object))
+	assert.Len(t, row.(*render.PodWithMetrics).Raw.Object, 5)
 }
 
 func TestTableMeta(t *testing.T) {
 	uu := map[string]struct {
-		gvr      string
+		gvr      *client.GVR
 		accessor dao.Accessor
 		renderer model1.Renderer
 	}{
 		"generic": {
-			gvr:      "containers",
+			gvr:      client.CoGVR,
 			accessor: &dao.Container{},
 			renderer: &render.Container{},
 		},
 		"node": {
-			gvr:      "v1/nodes",
+			gvr:      client.NodeGVR,
 			accessor: &dao.Node{},
 			renderer: &render.Node{},
 		},
-		"table": {
-			gvr:      "v1/events",
-			accessor: &dao.Table{},
-			renderer: &render.Event{},
-		},
 	}
 
 	for k := range uu {
 		u := uu[k]
-		ta := NewTable(client.NewGVR(u.gvr))
+		ta := NewTable(u.gvr)
 		m := resourceMeta(ta.gvr)
 
 		assert.Equal(t, u.accessor, m.DAO)
@@ -115,10 +111,10 @@ func mustLoad(n string) *unstructured.Unstructured {
 
 func load(t *testing.T, n string) *unstructured.Unstructured {
 	raw, err := os.ReadFile(fmt.Sprintf("testdata/%s.json", n))
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	var o unstructured.Unstructured
 	err = json.Unmarshal(raw, &o)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	return &o
 }
 
@@ -134,56 +130,56 @@ type testFactory struct {
 
 var _ dao.Factory = testFactory{}
 
-func (f testFactory) Client() client.Connection {
+func (testFactory) Client() client.Connection {
 	return client.NewTestAPIClient()
 }
 
-func (f testFactory) Get(gvr, path string, wait bool, sel labels.Selector) (runtime.Object, error) {
+func (f testFactory) Get(*client.GVR, string, bool, labels.Selector) (runtime.Object, error) {
 	if len(f.rows) > 0 {
 		return f.rows[0], nil
 	}
 	return nil, nil
 }
 
-func (f testFactory) List(gvr, ns string, wait bool, sel labels.Selector) ([]runtime.Object, error) {
+func (f testFactory) List(*client.GVR, string, bool, labels.Selector) ([]runtime.Object, error) {
 	if len(f.rows) > 0 {
 		return f.rows, nil
 	}
 	return nil, nil
 }
 
-func (f testFactory) ForResource(ns, gvr string) (informers.GenericInformer, error) {
+func (testFactory) ForResource(string, *client.GVR) (informers.GenericInformer, error) {
 	return nil, nil
 }
 
-func (f testFactory) CanForResource(ns, gvr string, verbs []string) (informers.GenericInformer, error) {
+func (testFactory) CanForResource(string, *client.GVR, []string) (informers.GenericInformer, error) {
 	return nil, nil
 }
-func (f testFactory) WaitForCacheSync() {}
-func (f testFactory) Forwarders() watch.Forwarders {
+func (testFactory) WaitForCacheSync() {}
+func (testFactory) Forwarders() watch.Forwarders {
 	return nil
 }
-func (f testFactory) DeleteForwarder(string) {}
+func (testFactory) DeleteForwarder(string) {}
 
 // ----------------------------------------------------------------------------
 
 type accessor struct {
-	gvr client.GVR
+	gvr *client.GVR
 }
 
 var _ dao.Accessor = (*accessor)(nil)
 
-func (a *accessor) SetIncludeObject(bool) {}
+func (*accessor) SetIncludeObject(bool) {}
 
-func (a *accessor) List(ctx context.Context, ns string) ([]runtime.Object, error) {
+func (*accessor) List(context.Context, string) ([]runtime.Object, error) {
 	return []runtime.Object{&render.PodWithMetrics{Raw: mustLoad("p1")}}, nil
 }
 
-func (a *accessor) Get(ctx context.Context, path string) (runtime.Object, error) {
+func (*accessor) Get(context.Context, string) (runtime.Object, error) {
 	return &render.PodWithMetrics{Raw: mustLoad("p1")}, nil
 }
 
-func (a *accessor) Init(_ dao.Factory, gvr client.GVR) {
+func (a *accessor) Init(_ dao.Factory, gvr *client.GVR) {
 	a.gvr = gvr
 }
 
