@@ -8,8 +8,10 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal"
+	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestSARender(t *testing.T) {
@@ -31,11 +33,11 @@ func TestSARender(t *testing.T) {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
 			o := load(t, u.file)
-			root := xray.NewTreeNode("serviceaccounts", "serviceaccounts")
+			root := xray.NewTreeNode(client.SaGVR, "serviceaccounts")
 			ctx := context.WithValue(context.Background(), xray.KeyParent, root)
 			ctx = context.WithValue(ctx, internal.KeyFactory, makeFactory())
 
-			assert.Nil(t, re.Render(ctx, "", o))
+			require.NoError(t, re.Render(ctx, "", o))
 			assert.Equal(t, u.level1, root.CountChildren())
 			assert.Equal(t, u.level2, root.Children[0].CountChildren())
 		})
